Die Firebase-Befehlszeile (GitHub) bietet eine Vielzahl von Tools zum Verwalten, Aufrufen und Bereitstellen von Firebase-Projekten.
Bevor Sie die Firebase-Befehlszeile verwenden, richten Sie ein Firebase-Projekt ein.
Befehlszeile einrichten oder aktualisieren
Firebase CLI installieren
Sie können die Firebase-Befehlszeile mit einer Methode installieren, die Ihrem Betriebssystem, Ihrem Erfahrungsgrad und/oder Ihrem Anwendungsfall entspricht. Unabhängig davon, wie Sie die Befehlszeile installieren, haben Sie Zugriff auf dieselben Funktionen und den Befehl firebase.
Windows
Sie können die Firebase-Befehlszeile für Windows mit einer der folgenden Optionen installieren:
| Option | Beschreibung | Empfohlen für… |
|---|---|---|
| eigenständige Binärdatei | Laden Sie die eigenständige Binärdatei für die Befehlszeile herunter. Anschließend können Sie auf die ausführbare Datei zugreifen, um eine Shell zu öffnen, in der Sie den Befehl firebase ausführen können.
|
Neue Entwickler Entwickler, die Node.js nicht verwenden oder nicht damit vertraut sind |
| npm | Verwenden Sie npm (den Node Package Manager), um die Befehlszeile zu installieren und den global verfügbaren Befehl firebase zu aktivieren.
|
Entwickler, die Node.js verwenden |
eigenständige Binärdatei
So laden Sie die Binärdatei für die Firebase-Befehlszeile herunter und führen sie aus:
Laden Sie die Firebase-CLI-Binärdatei für Windows herunter.
Greifen Sie auf die Binärdatei zu, um eine Shell zu öffnen, in der Sie den Befehl
firebaseausführen können.Fahren Sie mit Anmelden und CLI testen fort.
npm
So installieren Sie die Firebase-Befehlszeile mit npm (Node Package Manager):
Installieren Sie Node.js mit nvm-windows (Node Versionsmanager). Durch die Installation von Node.js werden die
npm-Befehlstools automatisch installiert.Installieren Sie die Firebase-Befehlszeile über
npm, indem Sie den folgenden Befehl ausführen:npm install -g firebase-tools
Mit diesem Befehl wird der global verfügbare Befehl
firebaseaktiviert.Fahren Sie mit Anmelden und CLI testen fort.
macOS oder Linux
Sie können die Firebase-Befehlszeile für macOS oder Linux mit einer der folgenden Optionen installieren:
| Option | Beschreibung | Empfohlen für… |
|---|---|---|
| automatisches Installationsskript | Führen Sie einen einzelnen Befehl aus, der Ihr Betriebssystem automatisch erkennt, die neueste CLI-Version herunterlädt und dann den global verfügbaren Befehl firebase aktiviert.
|
Neue Entwickler Entwickler, die Node.js nicht verwenden oder nicht damit vertraut sind Automatisierte Bereitstellungen in einer CI/CD-Umgebung |
| eigenständige Binärdatei | Laden Sie die eigenständige Binärdatei für die Befehlszeile herunter. Anschließend können Sie die Binärdatei so konfigurieren und ausführen, dass sie zu Ihrem Workflow passt. | Vollständig anpassbare Workflows über die Befehlszeile |
| npm | Verwenden Sie npm (den Node Package Manager), um die Befehlszeile zu installieren und den global verfügbaren Befehl firebase zu aktivieren.
|
Entwickler, die Node.js verwenden |
Skript für die automatische Installation
So installieren Sie die Firebase CLI mit dem automatischen Installationsskript:
Führen Sie den folgenden cURL-Befehl aus:
curl -sL https://firebase.tools | bash
Dieses Script erkennt automatisch Ihr Betriebssystem, lädt die neueste Firebase-CLI-Version herunter und aktiviert dann den global verfügbaren
firebase-Befehl.Fahren Sie mit Anmelden und CLI testen fort.
Weitere Beispiele und Details zum automatischen Installationsskript finden Sie im Quellcode des Skripts unter firebase.tools.
eigenständige Binärdatei
So laden Sie die Binärdatei für die Firebase-Befehlszeile herunter, die für Ihr Betriebssystem spezifisch ist, und führen sie aus:
Laden Sie die Binärdatei des Firebase-CLI für Ihr Betriebssystem herunter: macOS | Linux
(Optional) Richten Sie den global verfügbaren Befehl
firebaseein.- Machen Sie die Binärdatei ausführbar, indem Sie
chmod +x ./firebase_toolsausführen. - Fügen Sie den Pfad der Binärdatei Ihrem PATH hinzu.
- Machen Sie die Binärdatei ausführbar, indem Sie
Fahren Sie mit Anmelden und CLI testen fort.
npm
So installieren Sie die Firebase-Befehlszeile mit npm (Node Package Manager):
Installieren Sie Node.js mit nvm (dem Node Versionsmanager).
Bei der Installation von Node.js werden dienpm-Befehlstools automatisch installiert.Installieren Sie die Firebase-Befehlszeile über
npm, indem Sie den folgenden Befehl ausführen:npm install -g firebase-tools
Mit diesem Befehl wird der global verfügbare Befehl
firebaseaktiviert.Fahren Sie mit Anmelden und CLI testen fort.
Anmelden und Firebase-Befehlszeile testen
Nach der Installation der Befehlszeile müssen Sie sich authentifizieren. Anschließend können Sie die Authentifizierung bestätigen, indem Sie Ihre Firebase-Projekte auflisten.
Melden Sie sich mit Ihrem Google-Konto in Firebase an. Führen Sie dazu den folgenden Befehl aus:
firebase login
Mit diesem Befehl wird Ihr lokaler Computer mit Firebase verbunden und Sie erhalten Zugriff auf Ihre Firebase-Projekte.
Prüfen Sie, ob die Befehlszeile richtig installiert ist und auf Ihr Konto zugreift, indem Sie Ihre Firebase-Projekte auflisten. Führen Sie dazu diesen Befehl aus:
firebase projects:list
Die angezeigte Liste sollte mit den Firebase-Projekten in der Firebase Console übereinstimmen.
Auf die neueste CLI-Version aktualisieren
Im Allgemeinen sollten Sie die neueste Firebase-CLI-Version verwenden.
Wie Sie die CLI-Version aktualisieren, hängt von Ihrem Betriebssystem und der Art der Installation der CLI ab.
Windows
- Eigenständige Binärdatei: Laden Sie die neue Version herunter und ersetzen Sie sie auf Ihrem System.
- npm: Führen Sie
npm install -g firebase-toolsaus.
macOS
Automatisches Installationsskript: Führen Sie
curl -sL https://firebase.tools | upgrade=true bashaus.Eigenständige Binärdatei: Laden Sie die neue Version herunter und ersetzen Sie sie auf Ihrem System.
npm: Führen Sie
npm install -g firebase-toolsaus.
Linux
Automatisches Installationsskript: Führen Sie
curl -sL https://firebase.tools | upgrade=true bashaus.Eigenständige Binärdatei: Laden Sie die neue Version herunter und ersetzen Sie sie auf Ihrem System.
npm: Führen Sie
npm install -g firebase-toolsaus.
Firebase-Befehlszeile deinstallieren
Wie Sie die Befehlszeile deinstallieren, hängt von Ihrem Betriebssystem und der Art der Installation ab.
Windows
- Eigenständige Binärdatei: Löschen Sie die heruntergeladene
firebase.exe-Binärdatei. - npm: Führen Sie
npm uninstall -g firebase-toolsaus.
macOS
Automatisches Installationsskript: Führen Sie
curl -sL https://firebase.tools | uninstall=true bashaus.Eigenständige Binärdatei: Löschen Sie die heruntergeladene
firebase-Binärdatei. Wenn Sie den Speicherort der UmgebungsvariablenPATHhinzugefügt haben, entfernen Sie ihn.npm: Führen Sie
npm uninstall -g firebase-toolsaus.
Linux
Automatisches Installationsskript: Führen Sie
curl -sL https://firebase.tools | uninstall=true bashaus.Eigenständige Binärdatei: Löschen Sie die heruntergeladene
firebase-Binärdatei. Wenn Sie den Speicherort der UmgebungsvariablenPATHhinzugefügt haben, entfernen Sie ihn.npm: Führen Sie
npm uninstall -g firebase-toolsaus.
Befehlszeile mit CI-Systemen verwenden
Wir empfehlen, sich bei Verwendung der Befehlszeile mit CI-Systemen über Standardanmeldedaten für Anwendungen zu authentifizieren.
(Empfohlen) Standardanmeldedaten für Anwendungen verwenden
Die Firebase-Befehlszeile erkennt und verwendet Standardanmeldedaten für Anwendungen, wenn diese festgelegt sind. Die einfachste Möglichkeit, die Befehlszeile in CI- und anderen Headless-Umgebungen zu authentifizieren, besteht darin, Standardanmeldedaten für Anwendungen einzurichten.
(Legacy) FIREBASE_TOKEN verwenden
Alternativ können Sie sich mit FIREBASE_TOKEN authentifizieren. Dies ist weniger sicher als Standardanmeldedaten für Anwendungen und wird nicht mehr empfohlen.
Installieren Sie die Firebase-Befehlszeile auf einem Computer mit einem Browser.
Starten Sie den Anmeldevorgang mit dem folgenden Befehl:
firebase login:ci
Rufen Sie die angegebene URL auf und melden Sie sich mit einem Google-Konto an.
Geben Sie ein neues Aktualisierungstoken aus. Die aktuelle CLI-Sitzung ist davon nicht betroffen.
Speichern Sie das Ausgabetoken auf sichere, aber zugängliche Weise in Ihrem CI-System.
Verwenden Sie dieses Token, wenn Sie
firebase-Befehle ausführen. Sie haben die folgenden beiden Möglichkeiten:Option 1: Speichern Sie das Token als Umgebungsvariable
FIREBASE_TOKEN. Ihr System verwendet das Token automatisch.Option 2: Führen Sie alle
firebase-Befehle mit dem Flag--token TOKENin Ihrem CI-System aus.
Dies ist die Reihenfolge der Priorität für das Laden von Tokens: Flag, Umgebungsvariable, gewünschtes Firebase-Projekt.
Firebase-Projekt initialisieren
Für viele gängige Aufgaben, die mit der Befehlszeile ausgeführt werden, z. B. die Bereitstellung in einem Firebase-Projekt, ist ein Projektverzeichnis erforderlich. Sie erstellen ein Projektverzeichnis mit dem Befehl firebase init. Ein Projektverzeichnis ist in der Regel dasselbe Verzeichnis wie das Stammverzeichnis der Versionsverwaltung. Nach dem Ausführen von firebase init enthält das Verzeichnis eine firebase.json-Konfigurationsdatei.
Führen Sie den folgenden Befehl im Verzeichnis Ihrer App aus, um ein neues Firebase-Projekt zu initialisieren:
firebase init
Der Befehl firebase init führt Sie durch die Einrichtung Ihres Projektverzeichnisses und einiger Firebase-Produkte. Während der Projektinitialisierung werden Sie von der Firebase-Befehlszeile aufgefordert, die folgenden Aufgaben auszuführen:
Wählen Sie ein Firebase-Standardprojekt aus.
In diesem Schritt wird das aktuelle Projektverzeichnis mit einem Firebase-Projekt verknüpft, damit projektspezifische Befehle (z. B.
firebase deploy) für das entsprechende Firebase-Projekt ausgeführt werden.Es ist auch möglich, mehrere Firebase-Projekte (z. B. ein Staging-Projekt und ein Produktionsprojekt) mit demselben Projektverzeichnis zu verknüpfen.
Wählen Sie Firebase-Produkte aus, die Sie in Ihrem Firebase-Projekt einrichten möchten.
In diesem Schritt werden Sie aufgefordert, Konfigurationen für bestimmte Dateien für die ausgewählten Produkte oder Funktionen festzulegen. Weitere Informationen zu diesen Konfigurationen finden Sie in der Dokumentation des jeweiligen Produkts (z. B. Hosting oder Authentication). Sie können
firebase initjederzeit später ausführen, um weitere Firebase-Produkte einzurichten.
Am Ende der Initialisierung erstellt Firebase automatisch die folgenden beiden Dateien im Stammverzeichnis Ihres lokalen App-Verzeichnisses:
Eine
firebase.json-Konfigurationsdatei, in der Ihre Projektkonfiguration aufgeführt ist.Eine
.firebaserc-Datei, in der die Aliasse Ihres Projekts gespeichert sind.
Datei firebase.json
Mit dem Befehl firebase init wird im Stammverzeichnis Ihres Projektverzeichnisses eine firebase.json-Konfigurationsdatei erstellt.
Die Datei firebase.json ist erforderlich, um Assets mit der Firebase-CLI bereitzustellen, da sie angibt, welche Dateien und Einstellungen aus Ihrem Projektverzeichnis in Ihrem Firebase-Projekt bereitgestellt werden (z. B. Hosting-Einstellungen, Authentication-Anbieterkonfigurationen, Sicherheitsregeln und Cloud Functions-Konfiguration).
Da einige Einstellungen entweder in Ihrem Projektverzeichnis oder in der Firebase Console definiert werden können, müssen Sie alle potenziellen Bereitstellungskonflikte beheben.
Sie können die meisten Firebase Hosting-Optionen direkt in der Datei firebase.json konfigurieren. Für andere Firebase-Dienste, die mit der Firebase-CLI bereitgestellt werden können, erstellt der Befehl firebase init jedoch bestimmte Dateien, in denen Sie Einstellungen für diese Dienste definieren können, z. B. eine index.js-Datei für Cloud Functions. Sie können in der Datei firebase.json auch Predeploy- oder Postdeploy-Hooks einrichten.
Die folgende firebase.json-Datei ist ein umfassendes Beispiel, das Konfigurationsoptionen für viele Firebase-Dienste zeigt. Außerdem werden Funktionen wie Multi-Codebasis-Cloud Functions, Local Emulator Suite-Einrichtung und eine Remote Config-Vorlage demonstriert. Beachten Sie, dass eine firebase.json-Datei für ein bestimmtes Projekt nur Konfigurationen für die Firebase-Dienste enthält, die für dieses Projekt eingerichtet wurden (z. B. nur Firebase Hosting und Cloud Functions). Durch Hinzufügen des Schlüssels $schema werden die Validierung und die automatische Vervollständigung in vielen Code-Editoren aktiviert.
{
"$schema": "https://raw.githubusercontent.com/firebase/firebase-tools/master/schema/firebase-config.json",
"hosting": {
"public": "public",
"ignore": [
"firebase.json",
"**/.*",
"**/node_modules/**"
],
"cleanUrls": true,
"trailingSlash": false
},
"apphosting": {
"backendId": "my-app",
"rootDir": "backend",
"ignore": [
"firebase.json",
"**/.*",
"**/node_modules/**"
]
},
"firestore": {
"rules": "firestore.rules",
"indexes": "firestore.indexes.json"
},
"storage": {
"rules": "storage.rules"
},
"database": {
"rules": "database.rules.json"
},
"dataconnect": {
"source": "dataconnect",
"location": "us-central1"
},
"functions": [
{
"source": "functions",
"codebase": "default",
"ignore": [
"**/.*",
"**/node_modules/**"
],
"predeploy": [
"npm --prefix \"$RESOURCE_DIR\" run lint",
"npm --prefix \"$RESOURCE_DIR\" run build"
]
}
],
"emulators": {
"auth": {
"port": 9099
},
"functions": {
"port": 5001
},
"firestore": {
"port": 8080
},
"hosting": {
"port": 5000
},
"storage": {
"port": 9199
},
"ui": {
"enabled": true,
"port": 4000
},
"singleProjectMode": true
},
"extensions": {
"my-storage-resizer": "firebase/storage-resize-images@^0.1.0"
},
"auth": {
"providers": {
"anonymous": true,
"emailPassword": true,
"googleSignIn": {
"oAuthBrandDisplayName": "My App",
"supportEmail": "support@myapp.com"
}
}
},
"remoteconfig": {
"template": "remoteconfig.template.json"
}
}
Standardmäßig wird firebase.json verwendet. Sie können jedoch das Flag --config PATH übergeben, um eine alternative Konfigurationsdatei anzugeben.
Konfiguration für mehrere Cloud Firestore-Datenbanken
Wenn Sie firebase init ausführen, enthält Ihre firebase.json-Datei einen einzelnen firestore-Schlüssel, der der Standarddatenbank Ihres Projekts entspricht, wie im vorherigen Beispiel gezeigt.
Wenn Ihr Projekt mehrere Cloud Firestore-Datenbanken enthält, bearbeiten Sie die Datei firebase.json, um jeder Datenbank unterschiedliche Cloud Firestore Security Rules- und Datenbankindex-Quelldateien zuzuordnen. Ändern Sie die Datei mit einem JSON-Array, das einen Eintrag für jede Datenbank enthält.
"firestore": [
{
"database": "(default)",
"rules": "firestore.default.rules",
"indexes": "firestore.default.indexes.json"
},
{
"database": "ecommerce",
"rules": "firestore.ecommerce.rules",
"indexes": "firestore.ecommerce.indexes.json"
}
],
Cloud Functions Dateien, die bei der Bereitstellung ignoriert werden sollen
Bei der Bereitstellung der Funktion gibt die Befehlszeile automatisch eine Liste von Dateien im Verzeichnis functions an, die ignoriert werden sollen. Dadurch wird verhindert, dass überflüssige Dateien im Backend bereitgestellt werden, die die Datengröße Ihrer Bereitstellung erhöhen könnten.
Die Liste der standardmäßig ignorierten Dateien im JSON-Format:
"ignore": [
".git",
".runtimeconfig.json",
"firebase-debug.log",
"firebase-debug.*.log",
"node_modules"
]
Wenn Sie in firebase.json eigene benutzerdefinierte Werte für ignore hinzufügen, achten Sie darauf, dass die Liste der Dateien, die in der vorherigen Liste angezeigt wird, beibehalten wird (oder fügen Sie sie hinzu, falls sie fehlt).
Projekt-Aliasse verwalten
Sie können mehrere Firebase-Projekte mit demselben Projektverzeichnis verknüpfen.
Sie können beispielsweise ein Firebase-Projekt für die Bereitstellung und ein anderes für die Produktion verwenden. Durch die Verwendung verschiedener Projektumgebungen können Sie Änderungen vor der Bereitstellung in der Produktion prüfen. Mit dem Befehl firebase use können Sie zwischen Aliasen wechseln und neue Aliase erstellen.
Projekt-Alias hinzufügen
Wenn Sie während der Projektinitialisierung ein Firebase-Projekt auswählen, wird dem Projekt automatisch der Alias default zugewiesen. Wenn Sie jedoch projektspezifische Befehle für ein anderes Firebase-Projekt ausführen, aber weiterhin das selbe Projektverzeichnis verwenden möchten, führen Sie den folgenden Befehl in Ihrem Projektverzeichnis aus:
firebase use --add
Mit diesem Befehl werden Sie aufgefordert, ein anderes Firebase-Projekt auszuwählen und das Projekt als Alias zuzuweisen. Aliaszuweisungen werden in eine .firebaserc-Datei in Ihrem Projektverzeichnis geschrieben.
Projekt-Aliasse verwenden
Wenn Sie zugewiesene Firebase-Projektaliasse verwenden möchten, führen Sie einen der folgenden Befehle in Ihrem Projektverzeichnis aus.
| Befehl | Beschreibung |
|---|---|
firebase use |
Liste der definierten Aliasse für Ihr Projektverzeichnis ansehen |
firebase use \ |
Leitet alle Befehle an das angegebene Firebase-Projekt weiter.
Die Befehlszeile verwendet dieses Projekt als „aktives Projekt“. |
firebase use --clear |
Löscht das aktive Projekt.
Führen Sie |
firebase use \ |
Entfernt einen Alias aus Ihrem Projektverzeichnis. |
Sie können das aktive Projekt überschreiben, indem Sie das Flag --project mit einem beliebigen CLI-Befehl übergeben. Beispiel: Sie können die Befehlszeile so einrichten, dass sie für ein Firebase-Projekt ausgeführt wird, dem Sie den Alias staging zugewiesen haben. Wenn Sie einen einzelnen Befehl für das Firebase-Projekt ausführen möchten, dem Sie den Alias prod zugewiesen haben, können Sie beispielsweise ausführen.
Quellcodeverwaltung und Projekt-Aliasse
Im Allgemeinen sollten Sie die Datei .firebaserc in die Versionsverwaltung einchecken, damit Ihr Team Projekt-Aliasse freigeben kann. Bei Open-Source-Projekten oder Startervorlagen sollten Sie die Datei .firebaserc jedoch im Allgemeinen nicht einchecken.
Wenn Sie ein Entwicklungsprojekt haben, das nur für Sie bestimmt ist, können Sie entweder das Flag --project mit jedem Befehl übergeben oder firebase use PROJECT_ID ausführen, ohne dem Firebase-Projekt einen Alias zuzuweisen.
Firebase-Projekt lokal bereitstellen und testen
Sie können Ihr Firebase-Projekt auf lokal gehosteten URLs ansehen und testen, bevor Sie es in der Produktion bereitstellen. Wenn Sie nur bestimmte Funktionen testen möchten, können Sie eine durch Kommas getrennte Liste in einem Flag im Befehl firebase serve verwenden.
Führen Sie den folgenden Befehl im Stammverzeichnis Ihres lokalen Projektverzeichnisses aus, wenn Sie eine der folgenden Aufgaben ausführen möchten:
- Sehen Sie sich die statischen Inhalte für Ihre von Firebase gehostete Anwendung an.
- Verwenden Sie Cloud Functions, um dynamische Inhalte für Firebase Hosting zu generieren, und Sie möchten Ihre (bereitgestellten) Produktions-HTTP-Funktionen verwenden, um Hosting auf einer lokalen URL zu emulieren.
firebase serve --only hosting
Projekt mit lokalen HTTP-Funktionen emulieren
Führen Sie einen der folgenden Befehle in Ihrem Projektverzeichnis aus, um Ihr Projekt mit lokalen HTTP-Funktionen zu emulieren.
Verwenden Sie einen der folgenden Befehle, um HTTP-Funktionen und Hosting für Tests auf lokalen URLs zu emulieren:
firebase serve
firebase serve --only functions,hosting // uses a flag
Verwenden Sie den folgenden Befehl, um nur HTTP-Funktionen zu emulieren:
firebase serve --only functions
Von anderen lokalen Geräten aus testen
Standardmäßig antwortet firebase serve nur auf Anfragen von localhost. Das bedeutet, dass Sie über den Webbrowser Ihres Computers auf Ihre gehosteten Inhalte zugreifen können, aber nicht über andere Geräte in Ihrem Netzwerk. Wenn Sie von anderen lokalen Geräten aus testen möchten, verwenden Sie das Flag --host:
firebase serve --host 0.0.0.0 // accepts requests to any host
In einem Firebase-Projekt bereitstellen
Die Firebase-Befehlszeile verwaltet die Bereitstellung von Code und Assets in Ihrem Firebase-Projekt, einschließlich:
- Neue Versionen deiner Firebase Hosting Websites
- Neue, aktualisierte oder vorhandene Cloud Functions for Firebase
- Neue oder aktualisierte Schemas und Connectors für Firebase SQL Connect
- Security Rules für Firebase Realtime Database
- Security Rules für Cloud Storage for Firebase
- Security Rules für Cloud Firestore
- Indexe für Cloud Firestore
- Konfiguration für Authentication
Führen Sie den folgenden Befehl in Ihrem Projektverzeichnis aus, um die Bereitstellung in einem Firebase-Projekt vorzunehmen:
firebase deploy
Sie können optional einen Kommentar zu jeder Ihrer Bereitstellungen hinzufügen. Dieser Kommentar wird zusammen mit den anderen Bereitstellungsinformationen auf der Seite Firebase Hosting Ihres Projekts angezeigt. Beispiel:
firebase deploy -m "Deploying the best new feature ever."
Beachten Sie bei der Verwendung des Befehls firebase deploy Folgendes:
Wenn Sie Ressourcen aus einem Projektverzeichnis bereitstellen möchten, muss das Projektverzeichnis eine
firebase.json-Datei enthalten. Diese Datei wird automatisch mit dem Befehlfirebase initerstellt.Standardmäßig erstellt
firebase deployeinen Release für alle bereitstellbaren Ressourcen in Ihrem Projektverzeichnis. Wenn Sie bestimmte Firebase-Dienste oder -Funktionen bereitstellen möchten, verwenden Sie die teilweise Bereitstellung.
Bestimmte Firebase-Dienste bereitstellen
Wenn Sie nur bestimmte Firebase-Dienste oder -Funktionen bereitstellen möchten, können Sie eine durch Kommas getrennte Liste in einem Flag im Befehl firebase deploy verwenden. Mit dem folgenden Befehl werden beispielsweise Firebase Hosting-Inhalte und Cloud Storage Security Rules bereitgestellt.
firebase deploy --only hosting,storage
In der folgenden Tabelle sind die Dienste und Funktionen aufgeführt, die für die teilweise Bereitstellung verfügbar sind. Die Namen in den Flags entsprechen den Schlüsseln in Ihrer firebase.json-Konfigurationsdatei.
| Flag-Syntax | Dienst oder Funktion bereitgestellt |
|---|---|
--only auth |
Authentication-Anbieterkonfiguration |
--only database |
Firebase Realtime Database Security Rules |
--only dataconnect |
Firebase SQL Connect-Schemas und -Connectors |
--only firestore |
Cloud Firestore- und Security Rules-sowie-Indexe für alle konfigurierten Datenbanken |
--only functions |
Cloud Functions for Firebase |
--only hosting |
Inhalt auf Firebase Hosting |
--only storage |
Cloud Storage for Firebase Security Rules |
Bereitstellungskonflikte für Security Rules
Für Firebase Realtime Database, Cloud Storage for Firebase und Cloud Firestore können Sie Security Rules entweder in Ihrem lokalen Projektverzeichnis oder in der Firebase-Konsole definieren.
Eine weitere Möglichkeit, Bereitstellungskonflikte zu vermeiden, besteht darin, eine Teilbereitstellung zu verwenden und nur Security Rules in der Firebase Console zu definieren.
Skriptbasierte Aufgaben vor und nach der Bereitstellung einrichten
Sie können Shell-Skripts mit dem Befehl firebase deploy verbinden, um Aufgaben vor oder nach der Bereitstellung auszuführen. Ein Predeploy-Script könnte beispielsweise TypeScript-Code in JavaScript transpilieren und ein Postdeploy-Hook könnte Administratoren über neue Websitecontent-Bereitstellungen in Firebase Hosting benachrichtigen.
Wenn Sie Predeploy- oder Postdeploy-Hooks einrichten möchten, fügen Sie der Konfigurationsdatei firebase.json Bash-Skripts hinzu. Sie können kurze Skripts direkt in der Datei firebase.json definieren oder auf andere Dateien in Ihrem Projektverzeichnis verweisen.
Das folgende Script ist beispielsweise der firebase.json-Ausdruck für eine Post-Deployment-Aufgabe, die nach erfolgreichem Deployment in Firebase Hosting eine Slack-Nachricht sendet.
"hosting": {
// ...
"postdeploy": "./messageSlack.sh 'Just deployed to Firebase Hosting'",
"public": "public"
}
Die Skriptdatei messageSlack.sh befindet sich im Projektverzeichnis und sieht so aus:
curl -X POST -H 'Content-type: application/json' --data '{"text":"$1"}'
\https://SLACK_WEBHOOK_URLSie können predeploy- und postdeploy-Hooks für alle Assets einrichten, die Sie bereitstellen können. Wenn Sie firebase deploy ausführen, werden alle Aufgaben vor und nach der Bereitstellung ausgelöst, die in der Datei firebase.json definiert sind. Wenn Sie nur die Aufgaben ausführen möchten, die mit einem bestimmten Firebase-Dienst verknüpft sind, verwenden Sie Befehle für die teilweise Bereitstellung.
Sowohl der predeploy- als auch der postdeploy-Hook geben die Standardausgabe- und Fehlerstreams der Skripts im Terminal aus. Beachten Sie bei Fehlern Folgendes:
- Wenn ein Predeploy-Hook nicht wie erwartet abgeschlossen wird, wird die Bereitstellung abgebrochen.
- Wenn die Bereitstellung aus irgendeinem Grund fehlschlägt, werden Postdeploy-Hooks nicht ausgelöst.
Umgebungsvariablen
In Skripts, die in den Pre-Deploy- und Post-Deploy-Hooks ausgeführt werden, sind die folgenden Umgebungsvariablen verfügbar:
$GCLOUD_PROJECT: Die Projekt-ID des aktiven Projekts$PROJECT_DIR: Das Stammverzeichnis, das die Dateifirebase.jsonenthält$RESOURCE_DIR: (Nur fürhosting- undfunctions-Skripts) Der Speicherort des Verzeichnisses, das die bereitzustellenden Hosting- oder Cloud Functions-Ressourcen enthält.
Bereitstellungskontingente
Es ist möglich (wenn auch unwahrscheinlich), dass Sie ein Kontingent überschreiten, das die Rate oder das Volumen Ihrer Firebase-Bereitstellungsvorgänge begrenzt. Wenn Sie beispielsweise eine sehr große Anzahl von Funktionen bereitstellen, erhalten Sie möglicherweise die Fehlermeldung HTTP 429 Quota. Versuchen Sie, solche Probleme mit einer teilweisen Bereitstellung zu beheben.
Rollback eines Deployments durchführen
Sie können ein Rollback für ein Firebase Hosting-Deployment auf der Firebase Hosting-Seite Ihres Projekts durchführen, indem Sie die Aktion Rollback für den ausgewählten Release auswählen.
Es ist nicht möglich, Releases von Security Rules für Firebase Realtime Database, Cloud Storage for Firebase oder Cloud Firestore zurückzusetzen.
Befehlsreferenz
In diesem Abschnitt werden die verfügbaren Befehle für die folgenden Anwendungsfälle und Produkte beschrieben:
- Befehlszeilenbefehle für die Verwaltung
- Befehle für das Projektmanagement
- Bereitstellung und lokale Entwicklung
- App Distribution-Befehle
- App Hosting-Befehle
- Authentication-Befehle (Nutzerverwaltung)
- Cloud Firestore-Befehle
- Cloud Functions for Firebase-Befehle
- Crashlytics-Befehle
- Extensions-Befehle
- Extensions-Publisher-Befehle
- Hosting-Befehle
- Realtime Database-Befehle
- Remote Config-Befehle
- SQL Connect-Befehle
Befehlszeilenbefehle für die Verwaltung
| Befehl | Beschreibung |
|---|---|
help
|
Hilfeinformationen zur Befehlszeile oder zu bestimmten Befehlen anzeigen. |
init
|
Verknüpfen Sie ein neues Firebase-Projekt im aktuellen Verzeichnis und richten Sie es ein.
Mit diesem Befehl wird im aktuellen Verzeichnis die Konfigurationsdatei firebase.json erstellt.
|
login
|
Authentifizieren Sie die Befehlszeile mit Ihrem Google-Konto. Erfordert Zugriff auf einen Webbrowser.
Wenn Sie sich in Remote-Umgebungen, die keinen Zugriff auf |
login:ci
|
Veraltet.
Verwenden Sie stattdessen Standardanmeldedaten für Anwendungen mit einem Google Cloud-Dienstkonto (GOOGLE_APPLICATION_CREDENTIALS).
Generieren Sie ein Authentifizierungstoken für die Verwendung in nicht interaktiven Umgebungen. |
login:add
|
Melden Sie sich in einem zusätzlichen Google-Konto an. |
login:list
|
Alle authentifizierten Google-Konten auflisten. |
login:use \
|
Legen Sie das aktive Google-Konto fest. |
logout
|
Melden Sie sich in der Befehlszeile von Ihrem Google-Konto ab. |
open
|
Öffnen Sie einen Browser mit relevanten Projektressourcen. |
projects:list
|
Listen Sie alle Firebase-Projekte auf, auf die Sie Zugriff haben. |
use
|
Legen Sie das aktive Firebase-Projekt für die Befehlszeile fest. |
Projektmanagementbefehle
| Befehl | Beschreibung |
|---|---|
| Verwaltung von Firebase-Projekten | |
projects:addfirebase
|
Fügen Sie Firebase-spezifische Konfigurationen hinzu und aktivieren Sie Firebase-spezifische Dienste in einem vorhandenen Google Cloud-Projekt. |
projects:create
|
Erstellen Sie ein neues Google Cloud-Projekt, fügen Sie dann Firebase-spezifische Konfigurationen hinzu und aktivieren Sie Firebase-spezifische Dienste für das neue Projekt. |
projects:list
|
Listen Sie alle Firebase-Projekte auf, auf die Sie Zugriff haben. |
| Verwaltung von Firebase-Apps (iOS, Android, Web) | |
apps:create
|
Erstellen Sie eine neue Firebase-App. |
apps:list
|
Listet alle registrierten Firebase-Apps im aktiven Firebase-Projekt auf. |
apps:sdkconfig \
|
Gibt die Firebase-Konfiguration der angegebenen Firebase-App aus.
Wenn die Befehlszeile im nicht interaktiven Modus ausgeführt wird:
Dieser Befehl unterstützt das folgende optionale Flag:
|
| Verwaltung von SHA-Zertifikat-Hashes (nur Android) | |
apps:android:sha:create \
|
Fügt den angegebenen SHA-Zertifikat-Hash der angegebenen Firebase-Android-App hinzu. |
apps:android:sha:delete \
|
Löscht das angegebene SHA-Zertifikat (identifiziert durch SHA_ID aus apps:android:sha:list) aus der angegebenen Firebase-Android-App.
|
apps:android:sha:list \
|
Listet alle SHA-Zertifikat-Hashes für die angegebene Firebase-Android-App auf. |
Bereitstellung und lokale Entwicklung
Mit diesen Befehlen können Sie Ihr Firebase-Projekt bereitstellen und damit interagieren.
| Befehl | Beschreibung |
|---|---|
deploy
|
Stellt Code und Assets aus Ihrem Projektverzeichnis im aktiven Firebase-Projekt bereit.
Für diesen Befehl ist eine Weitere Informationen zum Bereitstellen in einem Firebase-Projekt |
serve
|
Starten Sie einen lokalen Server, um Ihre Firebase Hosting-Konfiguration und/oder die lokale HTTP-Cloud Functions zu testen (z. B. mit
Für diesen Befehl ist eine |
App Distribution-Befehle
| Befehl | Beschreibung |
|---|---|
appdistribution:distribute \
|
Laden Sie die angegebene Binärdatei für den Release (.apk, .aab oder .ipa) hoch und stellen Sie sie Testern für die angegebene Firebase-App zur Verfügung.
|
appdistribution:testers:add \
|
Fügen Sie dem aktiven Firebase-Projekt einen oder mehrere Tester (durch Leerzeichen getrennte EMAILS) hinzu. Wenn EMAILS weggelassen wird, müssen Sie Mit diesem Befehl werden nur Tester hinzugefügt, die noch nicht im Projekt sind. Vorhandene Tester werden nicht entfernt oder überschrieben. Dieser Befehl unterstützt die folgenden optionalen Flags:
|
appdistribution:testers:remove \
|
Tester (durch Leerzeichen getrennte EMAILS) aus dem aktiven Firebase-Projekt entfernen. Wenn EMAILS weggelassen wird, müssen Sie Dieser Befehl unterstützt die folgenden optionalen Flags:
|
appdistribution:testers:list
|
Tester im aktiven Firebase-Projekt auflisten. |
appdistribution:groups:create \
|
Erstellt eine Testergruppe mit der angegebenen DISPLAY_NAME und optionalen GROUP_ALIAS.
Wenn GROUP_ALIAS weggelassen wird, wird automatisch ein Alias aus DISPLAY_NAME generiert. |
appdistribution:groups:delete \
|
Löscht die Testergruppe mit dem angegebenen Alias. |
appdistribution:groups:list
|
Alle Testergruppen im aktiven Firebase-Projekt auflisten. |
App Hosting-Befehle
| Befehl | Beschreibung |
|---|---|
apphosting:backends:create \
|
Erstellen Sie die Sammlung verwalteter Ressourcen, die mit einer einzelnen Codebasis verknüpft sind, die ein App Hosting-Backend umfasst. Dieser Befehl unterstützt die folgenden optionalen (aber empfohlenen) Flags:
Dieser Befehl unterstützt auch die folgenden optionalen Flags:
Wenn die Befehlszeile im nicht interaktiven Modus ausgeführt wird, sind sowohl |
apphosting:backends:get \
|
Rufen Sie die Details, einschließlich der öffentlichen URL, des angegebenen App Hosting-Back-Ends ab.
Wenn mehrere Regionen ein Backend mit dem angegebenen BACKEND_ID enthalten, protokolliert die Befehlszeile eine Warnung und gibt das erste übereinstimmende Backend aus. Beachten Sie, dass dieser Befehl das Flag |
apphosting:backends:list
|
Alle aktiven App Hosting-Back-Ends im aktiven Firebase-Projekt auflisten. |
apphosting:backends:delete \
|
Löscht das angegebene App Hosting-Backend.
Die Befehlszeile zeigt eine Bestätigungsaufforderung an, bevor die Aktion ausgeführt wird. Wenn Sie die Bestätigungsaufforderung überspringen möchten (im nicht interaktiven Modus erforderlich), übergeben Sie die folgenden Flags:
Wenn mehrere Regionen ein Backend mit dem angegebenen BACKEND_ID enthalten, werden Sie von der Befehlszeile im interaktiven Modus aufgefordert, die zu löschenden Backends auszuwählen. Wenn |
apphosting:rollouts:create \
|
Erstellt einen manuell ausgelösten Roll-out für das angegebene App Hosting-Backend. Dieser Befehl unterstützt die folgenden optionalen, sich gegenseitig ausschließenden Flags. Wenn keines von beiden angegeben ist, werden Sie von der Befehlszeile aufgefordert, einen Zweig aus einer Liste auszuwählen. Im nicht interaktiven Modus ist die Angabe eines dieser Flags erforderlich.
Wenn mehrere Regionen ein Backend mit dem angegebenen BACKEND_ID enthalten, schlägt dieser Befehl sowohl im interaktiven als auch im nicht interaktiven Modus fehl. Beachten Sie, dass dieser Befehl das Flag |
apphosting:secrets:set \
|
Erstellen oder aktualisieren Sie ein Secret in Google Cloud Secret Manager mit der angegebenen SECRET_NAME. Dieser Befehl unterstützt das folgende optionale (aber empfohlene) Flag:
Dieser Befehl unterstützt auch das folgende optionale Flag:
Wenn die Befehlszeile im nicht interaktiven Modus ausgeführt wird, übergeben Sie |
apphosting:secrets:grantaccess \
|
Gewähren Sie einer Reihe von Nutzer- oder Gruppen-E-Mail-Adressen oder einem Dienstkonto eines Back-Ends Berechtigungen für die angegebenen Secrets. Auf die Secrets kann dann von App Hosting während der Erstellung oder Ausführung zugegriffen werden.
Sie können einen oder mehrere SECRET_NAME-Werte übergeben, die durch ein Komma getrennt sind. Sie müssen entweder So gewähren Sie einer Gruppe von Nutzern oder Gruppen-E‑Mail-Adressen Zugriff:
Gewähren Sie Zugriff auf das Dienstkonto eines Back-Ends:
|
apphosting:secrets:revokeaccess \
|
Widerrufen Sie die Berechtigungen für die angegebenen Secrets von einer Gruppe von Nutzer- oder Gruppen-E-Mails oder vom Dienstkonto eines Back-Ends.
Sie können einen oder mehrere SECRET_NAME-Werte übergeben, die durch ein Komma getrennt sind. Sie müssen entweder So entziehen Sie einer Reihe von Nutzer- oder Gruppen-E-Mail-Adressen den Zugriff:
Zugriff für das Dienstkonto eines Backends widerrufen:
|
apphosting:secrets:describe \
|
Ruft die Metadaten und Versionen für den angegebenen Secret-Namen ab. |
apphosting:secrets:access \
|
Greift auf den Wert des Secrets für den angegebenen Secret-Namen in der angegebenen Version zu.
Wenn [@VERSION] weggelassen wird, wird standardmäßig auf die aktuelle Version zugegriffen.
|
Authentication-Befehle (Nutzerverwaltung)
| Befehl | Beschreibung |
|---|---|
auth:export \
|
Exportiert die Nutzerkonten des aktiven Firebase-Projekts in eine JSON- oder CSV-Datei. Weitere Informationen finden Sie auf der Seite auth:import und auth:export. |
auth:import \
|
Importieren Sie die Nutzerkonten aus einer JSON- oder CSV-Datei in das aktive Firebase-Projekt. Weitere Informationen finden Sie auf der Seite auth:import und auth:export. |
Cloud Firestore-Befehle
| Befehl | Beschreibung |
|---|---|
firestore:locations
|
Listet die verfügbaren Standorte für Cloud Firestore-Datenbankinstanzen im aktiven Firebase-Projekt auf. Informationen zu den verfügbaren Standorten für die Standard-Edition, die Enterprise-Edition und die MongoDB-Kompatibilität. |
firestore:databases:create \
|
Erstellt die angegebene Cloud Firestore-Datenbankinstanz (im nativen Modus) am angegebenen Speicherort.
Dieser Befehl unterstützt die folgenden optionalen Flags:
|
firestore:databases:list |
Alle Cloud Firestore-Datenbankinstanzen im aktiven Firebase-Projekt auflisten. |
firestore:databases:get \
|
Rufen Sie die Datenbankkonfiguration für die angegebene Cloud Firestore-Datenbankinstanz ab.
Die Tabellenausgabe enthält die |
firestore:databases:update \
|
Aktualisieren Sie die Datenbankkonfiguration der angegebenen Cloud Firestore-Datenbankinstanz. Mindestens ein Flag ist erforderlich (weggelassene Flags behalten ihre aktuellen Einstellungen bei). Dieser Befehl unterstützt die folgenden Flags:
|
firestore:databases:delete \
|
Löscht die angegebene Cloud Firestore-Datenbankinstanz.
Die Befehlszeile zeigt eine Bestätigungsaufforderung an, bevor die Aktion ausgeführt wird. Wenn Sie die Bestätigungsaufforderung überspringen möchten (im nicht interaktiven Modus erforderlich), übergeben Sie das Flag |
firestore:indexes
|
Alle Indexe für eine Cloud Firestore-Datenbankinstanz auflisten. Dieser Befehl unterstützt das folgende optionale Flag:
|
firestore:delete \
|
Dokumente im angegebenen Datenbankpfad (PATH) aus einer Cloud Firestore-Datenbankinstanz löschen.
PATH ist erforderlich, sofern nicht Beachten Sie, dass beim Löschen von Cloud Firestore-Daten über die Befehlszeile Lese- und Löschkosten anfallen. Weitere Informationen finden Sie unter Informationen zur Abrechnung für Cloud Firestore. Dieser Befehl unterstützt die folgenden optionalen Flags:
Die Befehlszeile zeigt eine Bestätigungsaufforderung an, bevor die Aktion ausgeführt wird. Wenn Sie die Bestätigungsaufforderung überspringen möchten (im nicht interaktiven Modus erforderlich), übergeben Sie die folgenden Flags: |
Cloud Functions for Firebase-Befehle
Weitere Informationen finden Sie in der Dokumentation zur Umgebungskonfiguration.
| Befehl | Beschreibung |
|---|---|
functions:config:export
|
Exportieren Sie die Legacy-Laufzeitkonfiguration Dieser Befehl unterstützt die folgenden optionalen Flags:
|
functions:delete \
|
Löscht eine oder mehrere angegebene Funktionen aus dem aktiven Firebase-Projekt.
Die Befehlszeile zeigt eine Bestätigungsaufforderung an, bevor die Aktion ausgeführt wird. Wenn Sie die Bestätigungsaufforderung überspringen möchten (im nicht interaktiven Modus erforderlich), übergeben Sie die folgenden Flags: |
functions:list
|
Alle bereitgestellten Funktionen im aktiven Firebase-Projekt auflisten. |
functions:log
|
Logs von allen bereitgestellten Cloud Functions im aktiven Firebase-Projekt lesen. |
functions:secrets:access \
|
Greift auf den Wert des Secrets für den angegebenen Secret-Namen in der angegebenen Version zu.
Wenn [@VERSION] weggelassen wird, wird standardmäßig auf die aktuelle Version zugegriffen.
|
functions:secrets:destroy \
|
Löscht das angegebene Secret in der angegebenen Version.
Die Befehlszeile zeigt eine Bestätigungsaufforderung an, bevor eine Aktion ausgeführt wird. Diese wird im nicht interaktiven Modus ohne |
functions:secrets:get \
|
Ruft die Metadaten und Versionen für den angegebenen Secret-Namen ab. |
functions:secrets:prune
|
Zerstört alle nicht verwendeten Secrets im aktiven Firebase-Projekt. |
functions:secrets:set \
|
Erstellt oder aktualisiert das angegebene Secret. |
functions:shell
|
Starten Sie eine lokale interaktive Shell zum Testen von Funktionen. |
functions:config:clone \
|
Veraltet.
Standardmäßig deaktiviert. Führen Sie zuerst |
functions:config:get
|
Veraltet.
Rufen Sie die vorhandenen Konfigurationswerte der Cloud Functions des aktiven Firebase-Projekts ab. |
functions:config:set \
|
Veraltet.
Standardmäßig deaktiviert. Führen Sie zuerst |
functions:config:unset \
|
Veraltet.
Standardmäßig deaktiviert. Führen Sie zuerst |
Crashlytics-Befehle
| Befehl | Beschreibung |
|---|---|
crashlytics:mappingfile:generateid \
|
Generieren Sie eine eindeutige Zuordnungsdatei-ID in der angegebenen Android-Ressourcendatei (XML). |
crashlytics:mappingfile:upload \
|
Laden Sie eine Proguard-kompatible Zuordnungsdatei (TXT) für die angegebene Firebase-App hoch und verknüpfen Sie sie mit der Zuordnungsdatei-ID, die in der angegebenen Android-Ressourcendatei (XML) deklariert ist. |
crashlytics:symbols:upload \
|
Generieren Sie eine Crashlytics-kompatible Symboldatei für Abstürze nativer Android-Bibliotheken (z. B. Android NDK oder Android-Builds von Unity oder Flutter) und laden Sie sie auf Firebase-Server hoch.
Dieser Befehl wird nur unter Android unterstützt. Verwenden Sie für iOS-dSYMs das Skript |
Extensions-Befehle
| Befehl | Beschreibung |
|---|---|
ext
|
Informationen zur Verwendung von Firebase Extensions-Befehlen anzeigen.
Listet die im aktiven Projekt installierten Erweiterungsinstanzen auf. |
ext:configure \
|
Konfigurieren Sie die Parameterwerte einer Erweiterungsinstanz in Ihrem Erweiterungsmanifest neu. |
ext:info \
|
Detaillierte Informationen zu einer Erweiterung ausgeben. |
ext:install \
|
Fügen Sie Ihrem Erweiterungsmanifest eine neue Instanz einer Erweiterung hinzu. |
ext:sdk:install \
|
SDKs zum Definieren von Erweiterungen in Funktionen installieren. |
ext:list
|
Alle in einem Firebase-Projekt installierten Erweiterungsinstanzen auflisten.
Gibt die Instanz-ID für jede Erweiterung aus. |
ext:uninstall \
|
Entfernen Sie eine Erweiterungsinstanz aus Ihrem Erweiterungsmanifest. |
ext:update \
|
Aktualisieren Sie eine Erweiterungsinstanz in Ihrem Erweiterungsmanifest auf die aktuelle Version (oder auf die angegebene veröffentlichte UPDATE_SOURCE-Version). Beachten Sie, dass für UPDATE_SOURCE keine lokalen Pfade und URLs unterstützt werden.
Die Befehlszeile zeigt eine Bestätigungsaufforderung an, bevor die Aktion ausgeführt wird. Sie können |
ext:export
|
Exportieren Sie alle installierten Erweiterungsinstanzen aus Ihrem Projekt in Ihr Erweiterungsmanifest. |
Extensions-Publisher-Befehle
| Befehl | Beschreibung |
|---|---|
ext:dev:init
|
Initialisiert eine Codebasis für eine neue Erweiterung im aktuellen Verzeichnis. |
ext:dev:list \
|
Eine Liste aller von einem Publisher hochgeladenen Erweiterungen ausgeben. |
ext:dev:register
|
Deaktiviert.
Das Registrieren neuer Publisher-Profil-IDs wird nicht mehr unterstützt. |
ext:dev:deprecate \
|
Verwerfen Sie Erweiterungsversionen, die mit dem Versionsprädikat übereinstimmen.
Ein Versionsprädikat kann eine einzelne Version (z. B. 1.0.0) oder ein Versionsbereich (z. B. >1.0.0) sein.
Wenn kein Versionsprädikat angegeben wird, werden alle Versionen dieser Erweiterung verworfen. |
ext:dev:undeprecate \
|
Undeprecate (Einstellung aufheben) für Erweiterungsversionen, die dem Versionsprädikat entsprechen.
Ein Versionsprädikat kann eine einzelne Version (z. B. 1.0.0) oder ein Versionsbereich (z. B. >1.0.0) sein.
|
ext:dev:upload \
|
Neue Version einer Erweiterung hochladen |
ext:dev:usage \
|
Anzahl der Installationen und Nutzungsmesswerte für Erweiterungen anzeigen, die von einem Publisher hochgeladen wurden. |
Hosting-Befehle
| Befehl | Beschreibung |
|---|---|
hosting:disable
|
Die Bereitstellung von Firebase Hosting-Traffic für eine Hosting-Website beenden. Nachdem Sie diesen Befehl ausgeführt haben, wird unter der Hosting-URL der Website die Meldung „Website nicht gefunden“ angezeigt. Dieser Befehl unterstützt das folgende optionale Flag:
Die Befehlszeile zeigt eine Bestätigungsaufforderung an, bevor die Aktion ausgeführt wird. Wenn Sie die Bestätigungsaufforderung überspringen möchten (im nicht interaktiven Modus erforderlich), übergeben Sie die folgenden Flags: |
| Verwaltung von Hosting Websites | |
hosting:sites:create \
|
Erstellt eine neue Hosting-Website mit der angegebenen SITE_ID. Wenn die Befehlszeile im nicht interaktiven Modus ausgeführt wird, ist SITE_ID erforderlich. Dieser Befehl unterstützt das folgende optionale Flag:
|
hosting:sites:delete \
|
Löscht die angegebene Hosting-Website.
Die Befehlszeile zeigt eine Bestätigungsaufforderung an, bevor die Aktion ausgeführt wird. Wenn Sie die Bestätigungsaufforderung überspringen möchten (im nicht interaktiven Modus erforderlich), übergeben Sie die folgenden Flags: |
hosting:sites:get \
|
Ruft die Details zur angegebenen Hosting-Website ab.
Die Tabellenausgabe enthält die Website-ID, die Standard-URL und die Firebase-Web-App-ID (falls verknüpft). Zusätzliche Metadaten (z. B. ob die Website die |
hosting:sites:list
|
Listet alle Hosting-Websites im aktiven Firebase-Projekt auf. |
| Verwaltung von Vorschaukanälen | |
hosting:channel:create \
|
Erstellen Sie einen neuen Vorschaukanal für eine Hosting-Website mit der angegebenen CHANNEL_ID.
Wenn die Befehlszeile im nicht interaktiven Modus ausgeführt wird, ist CHANNEL_ID erforderlich. Dieser Befehl unterstützt das folgende optionale Flag:
|
hosting:channel:delete \
|
Löscht den angegebenen Vorschaukanal. Sie können den Live-Kanal einer Website nicht löschen. Dieser Befehl unterstützt das folgende optionale Flag:
Die Befehlszeile zeigt eine Bestätigungsaufforderung an, bevor die Aktion ausgeführt wird. Wenn Sie die Bestätigungsaufforderung überspringen möchten (im nicht interaktiven Modus erforderlich), übergeben Sie die folgenden Flags: |
hosting:channel:deploy \
|
Stellt die Hosting-Inhalte und -Konfiguration im angegebenen Vorschaukanal bereit.
Dieser Befehl unterstützt das folgende optionale Flag:
|
hosting:channel:list
|
Alle Kanäle (einschließlich des „Live“-Kanals) für eine Hosting-Website auflisten. Dieser Befehl unterstützt das folgende optionale Flag:
|
hosting:channel:open \
|
Öffnet einen Browser mit der URL des angegebenen Kanals oder gibt die URL zurück, wenn das Öffnen in einem Browser nicht möglich ist. Wenn die Befehlszeile im nicht interaktiven Modus ausgeführt wird, ist CHANNEL_ID erforderlich. Dieser Befehl unterstützt das folgende optionale Flag:
|
| Klonen von Versionen | |
hosting:clone \
|
Klonen Sie die zuletzt bereitgestellte Version auf dem angegebenen „Quellkanal“ auf den angegebenen „Zielkanal“. Mit diesem Befehl wird auch im angegebenen „Zielkanal“ bereitgestellt. Wenn der „Zielkanal“ noch nicht vorhanden ist, wird mit diesem Befehl ein neuer Vorschaukanal auf der „Zielwebsite“ Hosting erstellt, bevor die Bereitstellung im Kanal erfolgt. |
hosting:clone \
|
Klont die angegebene Version in den angegebenen „Zielkanal“. Mit diesem Befehl wird auch im angegebenen „Zielkanal“ bereitgestellt. Wenn der „Zielkanal“ noch nicht vorhanden ist, wird mit diesem Befehl ein neuer Vorschaukanal auf der „Zielwebsite“ Hosting erstellt, bevor die Bereitstellung im Kanal erfolgt. Sie finden die VERSION_ID im Hosting-Dashboard der Firebase-Konsole. |
Realtime Database-Befehle
Sie können Ihre erste Realtime Database-Standardinstanz in der Firebase Console oder mit dem allgemeinen firebase init-Workflow oder dem spezifischen firebase init database-Workflow erstellen.
Nachdem Instanzen erstellt wurden, können Sie sie wie unter Bestimmte Instanzen über die Befehlszeile verwalten und mit ihnen interagieren beschrieben verwalten.
| Befehl | Beschreibung |
|---|---|
database:get \
|
Daten am angegebenen Datenbankspeicherort (PATH) für eine Realtime Database-Instanz abrufen und als JSON anzeigen. Unterstützt Abfragen für indexierte Daten. Dieser Befehl unterstützt das folgende optionale Flag:
|
database:instances:create \
|
Erstellen Sie eine Realtime Database-Instanz mit der angegebenen DATABASE_NAME am angegebenen Speicherort. Dieser Befehl unterstützt das folgende optionale (aber empfohlene) Flag:
Sie können diesen Befehl nicht verwenden, um die Standardinstanz Realtime Database für das aktive Firebase-Projekt zu erstellen. Wenn das Projekt keine vorhandenen Realtime Database-Instanzen enthält, werden Sie aufgefordert, den |
database:instances:list
|
Listet alle Realtime Database-Instanzen im aktiven Firebase-Projekt auf. Dieser Befehl unterstützt das folgende optionale Flag:
|
database:profile
|
Erstellen Sie ein Profil der Vorgänge für eine Realtime Database-Instanz.
Dieser Befehl unterstützt das folgende optionale Flag:
|
database:push \
|
Neue Daten an eine Liste am angegebenen Datenbankspeicherort (PATH) in einer Realtime Database-Instanz übertragen.
Nimmt Eingaben aus einer Datei (INFILE), STDIN oder dem Flag Dieser Befehl unterstützt das folgende optionale Flag:
|
database:remove \
|
Löscht alle Daten am angegebenen Datenbankspeicherort (PATH) in einer Realtime Database-Instanz. Dieser Befehl unterstützt das folgende optionale Flag:
Die Befehlszeile zeigt eine Bestätigungsaufforderung an, bevor die Aktion ausgeführt wird. Wenn Sie die Bestätigungsaufforderung überspringen möchten (im nicht interaktiven Modus erforderlich), übergeben Sie die folgenden Flags: |
database:set \
|
Alle Daten am angegebenen Datenbankspeicherort (PATH) in einer Realtime Database-Instanz ersetzen.
Nimmt Eingaben aus einer Datei (INFILE), STDIN oder dem Flag Dieser Befehl unterstützt das folgende optionale Flag:
Die Befehlszeile zeigt eine Bestätigungsaufforderung an, bevor die Aktion ausgeführt wird. Wenn Sie die Bestätigungsaufforderung überspringen möchten (im nicht interaktiven Modus erforderlich), übergeben Sie die folgenden Flags: |
database:update \
|
Führt eine partielle Aktualisierung am angegebenen Datenbankspeicherort (PATH) in einer Realtime Database-Instanz durch.
Nimmt Eingaben aus einer Datei (INFILE), STDIN oder dem Flag Dieser Befehl unterstützt das folgende optionale Flag:
Die Befehlszeile zeigt eine Bestätigungsaufforderung an, bevor die Aktion ausgeführt wird. Wenn Sie die Bestätigungsaufforderung überspringen möchten (im nicht interaktiven Modus erforderlich), übergeben Sie die folgenden Flags: |
Remote Config-Befehle
Diese Befehle und ihre Anwendungsfälle werden unter Remote Config programmatisch ändern ausführlicher beschrieben.
| Befehl | Beschreibung |
|---|---|
remoteconfig:versions:list
|
Listen Sie alle Versionen der Vorlage Remote Config auf. Dieser Befehl unterstützt das folgende optionale Flag:
|
remoteconfig:get \
|
Rufen Sie die Details der Vorlage Remote Config in der angegebenen Version ab. Dieser Befehl unterstützt die folgenden optionalen (aber empfohlenen) Flags:
|
remoteconfig:rollback \
|
Führt ein Rollback der Vorlage Remote Config auf die angegebene vorherige Version durch. Dieser Befehl unterstützt das folgende optionale (aber empfohlene) Flag:
Die Befehlszeile zeigt eine Bestätigungsaufforderung an, bevor die Aktion ausgeführt wird. Wenn Sie die Bestätigungsaufforderung überspringen möchten (im nicht interaktiven Modus erforderlich), übergeben Sie die folgenden Flags: |
remoteconfig:experiments:list
|
Alle Remote Config-Tests im aktiven Firebase-Projekt auflisten. Dieser Befehl unterstützt die folgenden optionalen Flags:
|
remoteconfig:experiments:get \
|
Ruft die Details des angegebenen Remote Config-Experiments ab.
Die Tabellenausgabe enthält den Ressourcennamen, den Anzeigenamen, den Status ( |
remoteconfig:experiments:delete \
|
Löscht den angegebenen Remote Config-Test.
Die Befehlszeile zeigt eine Bestätigungsaufforderung an, bevor eine Aktion ausgeführt wird, und unterstützt kein |
remoteconfig:rollouts:list
|
Alle Remote Config-Roll-outs im aktiven Firebase-Projekt auflisten. Dieser Befehl unterstützt die folgenden optionalen Flags:
|
remoteconfig:rollouts:get \
|
Ruft die Details des angegebenen Remote Config-Roll-outs ab. |
remoteconfig:rollouts:delete \
|
Löscht den angegebenen Remote Config-Roll-out.
Die Befehlszeile zeigt eine Bestätigungsaufforderung an, bevor eine Aktion ausgeführt wird, und unterstützt kein |
SQL Connect-Befehle
Diese Befehle und ihre Anwendungsfälle werden im Referenzhandbuch zur SQL Connect-Befehlszeile ausführlicher beschrieben.
| Befehl | Beschreibung |
|---|---|
dataconnect:services:list
|
Alle bereitgestellten SQL Connect-Dienste im aktiven Firebase-Projekt auflisten. |
dataconnect:sql:diff
|
Zeigen Sie die Unterschiede zwischen einem lokalen SQL Connect-Schema und Ihrem Cloud SQL-Datenbankschema an. Dieser Befehl unterstützt die folgenden optionalen Flags:
|
dataconnect:sql:migrate
|
Migrieren Sie das Schema für Ihre Cloud SQL-Datenbank, damit es mit Ihrem lokalen SQL Connect-Schema übereinstimmt. Dieser Befehl unterstützt die folgenden optionalen Flags:
Im interaktiven Modus zeigt die Befehlszeile eine Bestätigungsaufforderung an, bevor eine Aktion ausgeführt wird. Im nicht interaktiven Modus werden nicht destruktive Migrationen automatisch ausgeführt, während destruktive Änderungen abgebrochen werden, es sei denn, Sie übergeben |
dataconnect:sql:grant \
|
Weisen Sie dem angegebenen EMAIL_ADDRESS des Nutzers oder Dienstkontos die angegebene SQL_ROLE (eine der folgenden: Dieser Befehl unterstützt die folgenden optionalen Flags:
|
dataconnect:sdk:generate
|
Typisierte SDKs für Ihre SQL Connect-Connectors generieren. Dieser Befehl unterstützt die folgenden optionalen Flags:
|